<!-- From: https://github.com/xiaokang2022/tkintertools/readme.md -->

<h1 align="center">MagicTK</h1>

<p align="center">
<code>MagicTK</code> 是基于 <code>tkinter</code> 的 <code>UI</code> 开发库。
<br/>
</p>

<p align="center">
<a href="https://github.com/CodeCrafter-TL/MagicTK/releases"><img alt="Version" src="https://img.shields.io/github/v/release/CodeCrafter-TL/MagicTK?include_prereleases&logo=github&label=Version" title="Latest Version" /></a>
<a href="https://github.com/CodeCrafter-TL/MagicTK"><img alt="Size" src="https://img.shields.io/github/languages/code-size/CodeCrafter-TL/MagicTK?label=Size&logo=github" title="Code Size"/></a>
<br/>
<a href="https://github.com/CodeCrafter-TL/MagicTK/watchers"><img alt="Watchers" src="https://img.shields.io/github/watchers/CodeCrafter-TL/MagicTK?label=Watchers&logo=github&style=flat" title="Watchers" /></a>
<a href="https://github.com/CodeCrafter-TL/MagicTK/forks"><img alt="Forks" src="https://img.shields.io/github/forks/CodeCrafter-TL/MagicTK?label=Forks&logo=github&style=flat" title="Forks" /></a>
<a href="https://github.com/CodeCrafter-TL/MagicTK/stargazers"><img alt="Stars" src="https://img.shields.io/github/stars/CodeCrafter-TL/MagicTK?label=Stars&color=gold&logo=github&style=flat" title="Stars" /></a>
<a href="https://github.com/CodeCrafter-TL/MagicTK/issues"><img alt="Issues" src="https://img.shields.io/github/issues/CodeCrafter-TL/MagicTK?label=Issues&logo=github" title="Issues" /></a>
<a href="https://github.com/CodeCrafter-TL/MagicTK/pulls"><img alt="Pull Requests" src="https://img.shields.io/github/issues-pr/CodeCrafter-TL/MagicTK?label=Pull%20Requests&logo=github" title="Pull Requests" /></a>
<a href="https://github.com/CodeCrafter-TL/MagicTK/discussions"><img alt="Discussions" src="https://img.shields.io/github/discussions/CodeCrafter-TL/MagicTK?label=Discussions&logo=github" title="Discussions" /></a>
</p>

<p align="center">
<a href="https://github.com/CodeCrafter-TL/MagicTK/pulse"><img alt="Insights" src="https://repobeats.axiom.co/api/embed/62f9219ff249a7ca23332171c3768bf9f125aed7.svg" /></a>
</p>

<p align="center">
    <a href="https://star-history.com/#CodeCrafter-TL/MagicTK&Date">
        <picture>
            <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=CodeCrafter-TL/MagicTK&type=Date&theme=dark" />
            <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=CodeCrafter-TL/MagicTK&type=Date" />
            <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=CodeCrafter-TL/MagicTK&type=Date" />
        </picture>
    </a>
</p>

📦 使用
----------------------

### ✅ 稳定版本

* 🔖 最新版本 : `1.0.0.beta1`
* 🕓 发布日期 : 2024-08-09
